<p>
    <a href="https://sylius.com" target="_blank">
        <img src="https://demo.sylius.com/assets/shop/img/logo.png" />
    </a>
</p>

# Installation
`composer require dedi/sylius-taxon-type-plugin`

Change your `config/bundles.php` file to add these lines for the plugin :

```php
   <?php
   
   return [
       //..
       Dedi\SyliusTaxonTypePlugin\DediSyliusTaxonTypePlugin::class => ['all' => true],
];
```

Import routing in your `config/routes.yaml` file:
```yaml
# config/routes.yaml

dedi_sylius_taxon_type_admin:
    resource: "@DediSyliusTaxonTypePlugin/Resources/config/admin_routing.yml"
    prefix: /admin
```

Import config in your `config/packages/_sylius.yaml` file:
```yaml
# config/packages/_sylius.yaml

imports:
      ...

    - { resource: "@DediSyliusTaxonTypePlugin/Resources/config/grids/brand_grid.yaml" }


sylius_taxonomy:
    resources:
        taxon:
            classes:
                model: Path\To\Your\Entity\Taxon
                interface: Path\To\Your\Entity\TaxonInterface
                repository: Dedi\SyliusTaxonTypePlugin\Repository\TaxonRepository
```

Import ui config in your `config/packages/sylius_ui.yaml` file:

```yaml
# config/packages/sylius_ui.yaml

imports:
    ...
        
    - { resource: "@DediSyliusTaxonTypePlugin/Resources/config/packages/sylius_ui.yaml" }
```

In your Taxon interface, add the following:
```php
use Sylius\Component\Core\Model\TaxonInterface as BaseTaxonInterface;

interface TaxonInterface extends TypedTaxonInterface, BaseTaxonInterface
{
    //...
}
```

In your Taxon class, add the following:
```php
use Sylius\Component\Core\Model\Taxon as BaseTaxon;

/**
 * @ORM\Entity
 * @ORM\Table(name="sylius_taxon")
 */
class Taxon extends BaseTaxon implements TaxonInterface
{
    use TaxonTypeTrait;
    //...
}
```

Create a new TaxonFactory:

```php
use Sylius\Component\Taxonomy\Factory\TaxonFactoryInterface as BaseTaxonFactoryInterface;

class TaxonFactory implements TaxonFactoryInterface
{
    private BaseTaxonFactoryInterface $decoratedFactory;

    public function __construct(BaseTaxonFactoryInterface $decoratedFactory)
    {
        $this->decoratedFactory = $decoratedFactory;
    }

    public function createNew(): TaxonInterface
    {
        /** @var TaxonInterface $taxon */
        $taxon = $this->decoratedFactory->createNew();
        $taxon->setType(TypedTaxonInterface::DEFAULT_TYPE);

        return $taxon;
    }

    public function createBrand(): TaxonInterface
    {
        /** @var TaxonInterface $taxon */
        $taxon = $this->decoratedFactory->createNew();
        $taxon->setType(TypedTaxonInterface::BRAND_TYPE);

        return $taxon;
    }
}
```

with its TaxonFactoryInterface

```php
interface TaxonFactoryInterface extends FactoryInterface
{
    public function createBrand(): TaxonInterface;
}
```

then import it in your `config/services.yaml` file:

```yaml
# config/services.yaml

services:
    Path\To\Your\Factory\TaxonFactory:
        decorates: 'sylius.factory.taxon'
        arguments:
            $decoratedFactory: '@sylius.custom_factory.taxon'
        public: false
```

Then migrate your database 
```bash
$ bin/console doctrine:migrations:diff
$ bin/console doctrine:migrations:migrate
```

Override file @SyliusAdminBundle/Taxon/_form.html.twig and add :
```twig
<div class="two fields">
    {{ form_row(form.enabled) }}
</div>
{{ form_row(form.type) }}
```
Override file @SyliusAdminBundle/Taxon/_treeWithButtons.html.twig and update this line :
```twig
{% for taxon in taxons|filter(taxon => taxon.id is not null and taxon.type == constant('Dedi\\SyliusTaxonTypePlugin\\Model\\TypedTaxonInterface::DEFAULT_TYPE')) %}
```